@@ -9,88 +9,110 @@ class GrundigSat1: public PIRKeysetMetaData
 {
 public:
   GrundigSat1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class GrundigSat2: public PIRKeysetMetaData
 {
 public:
   GrundigSat2(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class GrundigAmp1: public PIRKeysetMetaData
 {
 public:
   GrundigAmp1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class GrundigAudio1: public PIRKeysetMetaData
 {
 public:
   GrundigAudio1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class GrundigAudio2: public PIRKeysetMetaData
 {
 public:
   GrundigAudio2(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class GrundigVCR1: public PIRKeysetMetaData
 {
 public:
   GrundigVCR1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class GrundigVCR1a: public GrundigVCR1
 {
 public:
   GrundigVCR1a(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class GrundigTV1: public PIRKeysetMetaData
 {
 public:
   GrundigTV1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class GrundigTV2: public PIRKeysetMetaData
 {
 public:
   GrundigTV2(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class GrundigTV3: public PIRKeysetMetaData
 {
 public:
   GrundigTV3(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class GrundigDVD1: public PIRKeysetMetaData
 {
 public:
   GrundigDVD1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 #endif // GRUNDIG_H
